imodels.rule_list API documentation
Description: Generic class for models that take the form of a list of rules.

# Module `imodels.rule_list`

Generic class for models that take the form of a list of rules.

Expand source code

    '''Generic class for models that take the form of a list of rules.
    '''

## Sub-modules

`imodels.rule_list.bayesian_rule_list`

  bayesian rule list (based on this implementation) - learn a compact …

`imodels.rule_list.corels_wrapper`
`imodels.rule_list.greedy_rule_list`

  Greedy rule list. Greedily splits on one feature at a time along a single path.

`imodels.rule_list.one_r`

  The oneR algorithm returns a rule list that splits on only one (usually continuous) feature It works by building a greedy rule list using only one …

`imodels.rule_list.rule_list`